Crate sz_orm_logger

Crate sz_orm_logger 

SZ-ORM Logger — Structured Logging

Provides multi-level (Debug/Info/Warn/Error), multi-output-target logging, supports async writing and structured fields, can compose multiple Logger implementations to output to different backends.

Main Types

Advanced Logging Features (advanced module)

Modules

advanced
高级日志功能:日志轮转、多输出、级别过滤、结构化字段
log_pipeline
日志管道:过滤器链、路由器、格式化器链与输出器链

Structs

LogEntry
LoggerFactory
Factory that creates loggers with different configurations.
Metrics
MetricsSnapshot
StructuredLogger

Enums

EnvKind
Environment type
LogLevel

Traits

Logger